#%% begin initialize textsearch_ja-8.4.2-8.3.7-i586-P1
/bin/chown postgres:pgsql /opt/postgresql-8.3.7/lib/libtextsearch_ja.so
/bin/chown postgres:pgsql /opt/postgresql-8.3.7/share/contrib/textsearch_ja.sql
/bin/chown postgres:pgsql /opt/postgresql-8.3.7/share/contrib/uninstall_textsearch_ja.sql
/bin/chown postgres:pgsql /opt/postgresql-8.3.7/doc/contrib/README.textsearch_ja 
#%% end
